#######
Dataset
#######

.. image:: ../../images/diagram_volumes.svg
   :alt: Training with volumes

.. currentmodule:: torchio.data


:class:`SubjectsDataset`
------------------------

.. autoclass:: SubjectsDataset
    :members:
